@@ -3,6 +3,7 @@
 // SPDX-License-Identifier: BSD-3-Clause
 #include "pqParaViewMenuBuilders.h"
 
+#include "pqImportReaction.h"
 #include "ui_pqEditMenuBuilder.h"
 #include "ui_pqFileMenuBuilder.h"
 
@@ -28,6 +29,7 @@
 #include "pqChangeFileNameReaction.h"
 #include "pqChangePipelineInputReaction.h"
 #include "pqColorToolbar.h"
+#include "pqConfigureCategoriesReaction.h"
 #include "pqCopyReaction.h"
 #include "pqCreateCustomFilterReaction.h"
 #include "pqCustomViewpointsDefaultController.h"
@@ -54,7 +56,6 @@
 #include "pqMainControlsToolbar.h"
 #include "pqManageCustomFiltersReaction.h"
 #include "pqManageExpressionsReaction.h"
-#include "pqManageFavoritesReaction.h"
 #include "pqManageLinksReaction.h"
 #include "pqManagePluginsReaction.h"
 #include "pqPVApplicationCore.h"
@@ -95,6 +96,7 @@
 #include "pqTraceReaction.h"
 #endif
 
+#include <QAction>
 #include <QApplication>
 #include <QCoreApplication>
 #include <QDockWidget>
@@ -160,6 +162,7 @@ void pqParaViewMenuBuilders::buildFileMenu(QMenu& menu)
   new pqSaveAnimationReaction(ui.actionFileSaveAnimation);
   new pqSaveAnimationGeometryReaction(ui.actionFileSaveGeometry);
 
+  new pqImportReaction(ui.actionImport);
   new pqExportReaction(ui.actionExport);
 #if VTK_MODULE_ENABLE_ParaView_pqPython
   new pqAnimatedExportReaction(ui.actionAnimatedExport);
@@ -191,6 +194,7 @@ void pqParaViewMenuBuilders::buildEditMenu(QMenu& menu, pqPropertiesPanel* prope
   new pqIgnoreSourceTimeReaction(ui.actionIgnoreTime);
   new pqDeleteReaction(ui.actionDelete);
   ui.actionDelete->setShortcut(QKeySequence(Qt::ALT + Qt::Key_D));
+  ui.actionDelete->setAutoRepeat(false);
   new pqDeleteReaction(ui.actionDeleteTree, pqDeleteReaction::DeleteModes::TREE);
   new pqDeleteReaction(ui.actionDelete_All, pqDeleteReaction::DeleteModes::ALL);
   new pqShowHideAllReaction(ui.actionShow_All, pqShowHideAllReaction::ActionType::Show);
@@ -212,9 +216,11 @@ void pqParaViewMenuBuilders::buildEditMenu(QMenu& menu, pqPropertiesPanel* prope
     QAction* applyAction = new QAction(QIcon(":/pqWidgets/Icons/pqApply.svg"),
       QCoreApplication::translate("pqEditMenu", "Apply"), &menu);
     applyAction->setShortcut(QKeySequence(Qt::ALT + Qt::Key_A));
+    applyAction->setAutoRepeat(false);
     QAction* resetAction = new QAction(QIcon(":/pqWidgets/Icons/pqCancel.svg"),
       QCoreApplication::translate("pqEditMenu", "Reset"), &menu);
     resetAction->setShortcut(QKeySequence(Qt::ALT + Qt::Key_R));
+    resetAction->setAutoRepeat(false);
     menu.insertAction(ui.actionDelete, applyAction);
     menu.insertAction(ui.actionDelete, resetAction);
     new pqApplyPropertiesReaction(propertiesPanel, applyAction, true);
@@ -246,10 +252,9 @@ void pqParaViewMenuBuilders::buildFiltersMenu(
   menu.setStyle(style);
 
   pqProxyGroupMenuManager* mgr =
-    new pqProxyGroupMenuManager(&menu, "ParaViewFilters", quickLaunchable);
+    new pqProxyGroupMenuManager(&menu, "ParaViewFilters", quickLaunchable, true);
   mgr->addProxyDefinitionUpdateListener("filters");
   mgr->setRecentlyUsedMenuSize(10);
-  mgr->setEnableFavorites(true);
   pqFiltersMenuReaction* menuReaction = new pqFiltersMenuReaction(mgr, hideDisabled);
 
   // Connect the filters menu about to show and the quick-launch dialog about to show
@@ -322,14 +327,16 @@ void pqParaViewMenuBuilders::buildToolsMenu(QMenu& menu)
     menu.addAction(QCoreApplication::translate("pqToolsMenu", "Manage Plugins..."))
     << pqSetName("actionManage_Plugins"));
 
-  QMenu* dummyMenu = new QMenu();
-  pqProxyGroupMenuManager* mgr = new pqProxyGroupMenuManager(dummyMenu, "ParaViewFilters", false);
+  QMenu* dummyMenu = new QMenu(&menu);
+  pqProxyGroupMenuManager* mgr =
+    new pqProxyGroupMenuManager(dummyMenu, "ParaViewFilters", false, true);
   mgr->addProxyDefinitionUpdateListener("filters");
 
-  QAction* manageFavoritesAction =
-    menu.addAction(QCoreApplication::translate("pqToolsMenu", "Manage Favorites..."))
-    << pqSetName("actionManage_Favorites");
-  new pqManageFavoritesReaction(manageFavoritesAction, mgr);
+  QAction* configureCategoriesAction =
+    menu.addAction(QCoreApplication::translate("pqToolsMenu", "Configure Categories"))
+    << pqSetName("actionConfigureCategories");
+  configureCategoriesAction->setMenuRole(QAction::NoRole);
+  new pqConfigureCategoriesReaction(configureCategoriesAction, mgr);
 
   new pqCustomizeShortcutsReaction(
     menu.addAction(QCoreApplication::translate("pqToolsMenu", "Customize Shortcuts..."))
@@ -363,6 +370,11 @@ void pqParaViewMenuBuilders::buildToolsMenu(QMenu& menu)
 
 #if VTK_MODULE_ENABLE_ParaView_pqPython
   menu.addSeparator(); // --------------------------------------------------
+
+  new pqEditMacrosReaction(
+    menu.addAction(QCoreApplication::translate("pqMacrosMenu", "Manage Macros"))
+    << pqSetName("actionMacroEdit"));
+
   new pqTraceReaction(menu.addAction(QCoreApplication::translate("pqToolsMenu", "Start Trace"))
       << pqSetName("actionToolsStartStopTrace"),
     QCoreApplication::translate("pqToolsMenu", "Start Trace"),
@@ -675,6 +687,7 @@ void pqParaViewMenuBuilders::buildHelpMenu(QMenu& menu)
   QAction* guide = menu.addAction(QCoreApplication::translate("pqHelpMenu", "ParaView Guide"));
   guide->setObjectName("actionGuide");
   guide->setShortcut(QKeySequence::HelpContents);
+  guide->setAutoRepeat(false);
   if (guideLocalFile.exists())
   {
     guide->setIcon(QIcon(":/pqWidgets/Icons/pdf.png"));
@@ -850,6 +863,8 @@ void pqParaViewMenuBuilders::buildToolbars(QMainWindow& mainWindow)
     mainWindow.addToolBar(Qt::TopToolBarArea, macrosToolbar);
   }
 #endif
+
+  mainWindow.addToolBarBreak();
 }
 
 //-----------------------------------------------------------------------------
